@@ -17,31 +17,36 @@
 
 #include "gridftp_exist.h"
 
-const Glib::Quark scope_exist("GridftpModule::file_exist");
+static Glib::Quark gfal_gridftp_scope_exist(){
+    return Glib::Quark ("GridftpModule::file_exist");
+}
 
-bool gridftp_module_file_exist(GridFTP_session* sess, const char * url){
+bool gridftp_module_file_exist(gfal2_context_t context, GridFTP_session* sess, const char * url){
 	
 	gfal_log(GFAL_VERBOSE_TRACE,"   -> [gridftp_module_file_exist]");
 	
 
 	std::auto_ptr<GridFTP_Request_state> req(new GridFTP_Request_state(sess, false));
+    GridFTPOperationCanceler canceler(context, req.get());
 
+    req->start();
 	globus_result_t res = globus_ftp_client_exists(
 				req->sess->get_ftp_handle(),
 				url,
                 req->sess->get_op_attr_ftp(),
 				globus_basic_client_callback,
 				req.get());
-	gfal_globus_check_result(scope_exist, res);
-	gridftp_poll_callback(scope_exist, req.get());
+    gfal_globus_check_result(gfal_gridftp_scope_exist(), res);
+    req->poll_callback(gfal_gridftp_scope_exist());
+
 	gfal_log(GFAL_VERBOSE_TRACE,"   <- [gridftp_module_file_exist]");	
-	switch(req->errcode){
+	switch(req->get_error_code()){
 		case 0:
 			return true;
 		case ENOENT:
 			return false;
 		default:
-			gridftp_callback_err_report(scope_exist, req.get());
+            req->err_report(gfal_gridftp_scope_exist());
 		
 	}
 	return false;	
